@@ -390,6 +390,7 @@ void BrowseMainPage::saveConfig() const
 
 bool BrowseMainPage::eventFilter(QObject* watched, QEvent* event)
 {
+    // Leave fullscreen when not viewing an image
     if (window()->isFullScreen() && event->type() == QEvent::ShortcutOverride) {
         const QKeyEvent* keyEvent = static_cast<QKeyEvent*>(event);
         if (keyEvent->key() == Qt::Key_Escape) {
@@ -397,7 +398,6 @@ bool BrowseMainPage::eventFilter(QObject* watched, QEvent* event)
            event->accept();
         }
     }
-
     return QWidget::eventFilter(watched, event);
 }
 
@@ -563,7 +563,7 @@ void BrowseMainPage::slotUrlsDropped(const QUrl &destUrl, QDropEvent* event)
     // We can't call FileOperations::showMenuForDroppedUrls() directly because
     // we need the slot to return so that the drop event is accepted. Otherwise
     // the drop cursor is still visible when the menu is shown.
-    QMetaObject::invokeMethod(this, "showMenuForDroppedUrls", Qt::QueuedConnection, Q_ARG(QList<QUrl>, urlList), Q_ARG(QUrl, destUrl));
+    QMetaObject::invokeMethod(this, [this, urlList, destUrl]() { showMenuForDroppedUrls(urlList, destUrl); }, Qt::QueuedConnection);
 }
 
 void BrowseMainPage::showMenuForDroppedUrls(const QList<QUrl>& urlList, const QUrl &destUrl)
