@@ -25,6 +25,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 // Qt
 #include <QApplication>
 #include <QAction>
+#include <QRect>
 #include "gwenview_app_debug.h"
 
 // KDE
@@ -66,6 +67,7 @@ struct ImageOpsContextManagerItem::Private
     ImageOpsContextManagerItem* q;
     MainWindow* mMainWindow;
     SideBarGroup* mGroup;
+    QRect* mCropStateRect;
 
     QAction * mRotateLeftAction;
     QAction * mRotateRightAction;
@@ -81,25 +83,25 @@ struct ImageOpsContextManagerItem::Private
         KActionCollection* actionCollection = mMainWindow->actionCollection();
         KActionCategory* edit = new KActionCategory(i18nc("@title actions category - means actions changing image", "Edit"), actionCollection);
 
-        mRotateLeftAction = edit->addAction("rotate_left", q, SLOT(rotateLeft()));
+        mRotateLeftAction = edit->addAction(QStringLiteral("rotate_left"), q, SLOT(rotateLeft()));
         mRotateLeftAction->setText(i18n("Rotate Left"));
         mRotateLeftAction->setToolTip(i18nc("@info:tooltip", "Rotate image to the left"));
-        mRotateLeftAction->setIcon(QIcon::fromTheme("object-rotate-left"));
+        mRotateLeftAction->setIcon(QIcon::fromTheme(QStringLiteral("object-rotate-left")));
         actionCollection->setDefaultShortcut(mRotateLeftAction, Qt::CTRL + Qt::SHIFT + Qt::Key_R);
 
-        mRotateRightAction = edit->addAction("rotate_right", q, SLOT(rotateRight()));
+        mRotateRightAction = edit->addAction(QStringLiteral("rotate_right"), q, SLOT(rotateRight()));
         mRotateRightAction->setText(i18n("Rotate Right"));
         mRotateRightAction->setToolTip(i18nc("@info:tooltip", "Rotate image to the right"));
-        mRotateRightAction->setIcon(QIcon::fromTheme("object-rotate-right"));
+        mRotateRightAction->setIcon(QIcon::fromTheme(QStringLiteral("object-rotate-right")));
         actionCollection->setDefaultShortcut(mRotateRightAction, Qt::CTRL + Qt::Key_R);
 
-        mMirrorAction = edit->addAction("mirror", q, SLOT(mirror()));
+        mMirrorAction = edit->addAction(QStringLiteral("mirror"), q, SLOT(mirror()));
         mMirrorAction->setText(i18n("Mirror"));
-        mMirrorAction->setIcon(QIcon::fromTheme("object-flip-horizontal"));
+        mMirrorAction->setIcon(QIcon::fromTheme(QStringLiteral("object-flip-horizontal")));
 
-        mFlipAction = edit->addAction("flip", q, SLOT(flip()));
+        mFlipAction = edit->addAction(QStringLiteral("flip"), q, SLOT(flip()));
         mFlipAction->setText(i18n("Flip"));
-        mFlipAction->setIcon(QIcon::fromTheme("object-flip-vertical"));
+        mFlipAction->setIcon(QIcon::fromTheme(QStringLiteral("object-flip-vertical")));
 
         mResizeAction = edit->addAction("resize", q, SLOT(resizeImage()));
         mResizeAction->setText(i18n("Resize"));
@@ -153,6 +155,7 @@ ImageOpsContextManagerItem::ImageOpsContextManagerItem(ContextManager* manager,
     d->mGroup = new SideBarGroup(i18n("Image Operations"));
     setWidget(d->mGroup);
     EventWatcher::install(d->mGroup, QEvent::Show, this, SLOT(updateSideBarContent()));
+    d->mCropStateRect = new QRect;
     d->setupActions();
     updateActions();
     connect(contextManager(), &ContextManager::selectionChanged,
@@ -165,6 +168,7 @@ ImageOpsContextManagerItem::ImageOpsContextManagerItem(ContextManager* manager,
 
 ImageOpsContextManagerItem::~ImageOpsContextManagerItem()
 {
+    delete d->mCropStateRect;
     delete d;
 }
 
@@ -256,14 +260,36 @@ void ImageOpsContextManagerItem::crop()
         qCCritical(GWENVIEW_APP_LOG) << "No ImageView available!";
         return;
     }
+
     CropTool* tool = new CropTool(imageView);
+    Document::Ptr doc = DocumentFactory::instance()->load(contextManager()->currentUrl());
+    QSize size = doc->size();
+    QRect sizeAsRect = QRect(0, 0, size.width(), size.height());
+
+    if (!d->mCropStateRect->isNull() && sizeAsRect.contains(*d->mCropStateRect)) {
+        tool->setRect(*d->mCropStateRect);
+    }
+
     connect(tool, &CropTool::imageOperationRequested, this, &ImageOpsContextManagerItem::applyImageOperation);
-    connect(tool, &CropTool::done, this, &ImageOpsContextManagerItem::restoreDefaultImageViewTool);
+    connect(tool, &CropTool::rectReset, this, [this](){
+            this->resetCropState();
+        });
+    connect(tool, &CropTool::done, this, [this, tool]() {
+            this->d->mCropStateRect->setTopLeft(tool->rect().topLeft());
+            this->d->mCropStateRect->setSize(tool->rect().size());
+            this->restoreDefaultImageViewTool();
+        });
 
     d->mMainWindow->setDistractionFreeMode(true);
     imageView->setCurrentTool(tool);
 }
 
+void ImageOpsContextManagerItem::resetCropState()
+{
+    // Set the rect to null (see QRect::isNull())
+    d->mCropStateRect->setRect(0, 0, -1, -1);
+}
+
 void ImageOpsContextManagerItem::startRedEyeReduction()
 {
     if (!d->ensureEditable()) {
