@@ -40,10 +40,8 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Cambridge, MA 02110-1301, USA
 #include <KIO/DesktopExecParser>
 
 // KIPI
-#include <kipi/imagecollectionshared.h>
 #include <kipi/imageinfo.h>
 #include <kipi/imageinfoshared.h>
-#include <kipi/plugin.h>
 #include <kipi/pluginloader.h>
 
 // local
@@ -320,7 +318,7 @@ void KIPIInterface::loadOnePlugin()
         // If we reach this point, we just loaded one plugin. Go back to the
         // event loop. We will come back to load the remaining plugins or create
         // the menu later
-        QMetaObject::invokeMethod(this, "loadOnePlugin", Qt::QueuedConnection);
+        QMetaObject::invokeMethod(this, &KIPIInterface::loadOnePlugin, Qt::QueuedConnection);
         return;
     }
 
