@@ -24,7 +24,6 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 #include <QCheckBox>
 #include <QItemSelectionModel>
 #include <QShortcut>
-#include <QToolButton>
 #include <QVBoxLayout>
 #include "gwenview_app_debug.h"
 #include <QMenu>
@@ -45,7 +44,6 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 #include "fileoperations.h"
 #include <gvcore.h>
 #include "splitter.h"
-#include <lib/document/document.h>
 #include <lib/documentview/abstractdocumentviewadapter.h>
 #include <lib/documentview/abstractrasterimageviewtool.h>
 #include <lib/documentview/documentview.h>
@@ -718,8 +716,10 @@ void ViewMainPage::openUrls(const QList<QUrl>& allUrls, const QUrl &currentUrl)
         DocumentView::Setup savedSetup = d->mDocumentViewContainer->savedSetup(url);
         view->openUrl(url, d->mZoomMode == ZoomMode::Individual && savedSetup.valid ? savedSetup : setup);
 #ifdef KF5Activities_FOUND
-        d->mActivityResources.value(view)->setUri(url);
-        d->mActivityResources.value(view)->setMimetype(MimeTypeUtils::urlMimeType(url));
+        if (GwenviewConfig::historyEnabled()) {
+            d->mActivityResources.value(view)->setUri(url);
+            d->mActivityResources.value(view)->setMimetype(MimeTypeUtils::urlMimeType(url));
+        }
 #endif
     }
 
@@ -817,6 +817,11 @@ bool ViewMainPage::eventFilter(QObject* watched, QEvent* event)
                 }
             }
         }
+        // Leave fullscreen when viewing an image
+        if (window()->isFullScreen() && key == Qt::Key_Escape) {
+            d->mActionCollection->action("leave_fullscreen")->trigger();
+            event->accept();
+        }
     }
     
     return QWidget::eventFilter(watched, event);
