@@ -24,7 +24,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Cambridge, MA 02110-1301, USA
 // Qt
 
 // KDE
-#include <QDebug>
+#include "gwenview_importer_debug.h"
 #include <KDirLister>
 
 // Local
@@ -65,7 +65,7 @@ void DocumentDirFinder::start()
 
 void DocumentDirFinder::slotItemsAdded(const QUrl& dir, const KFileItemList& list)
 {
-    Q_FOREACH(const KFileItem & item, list) {
+    for (const KFileItem & item : list) {
         MimeTypeUtils::Kind kind = MimeTypeUtils::fileItemKind(item);
         switch (kind) {
         case MimeTypeUtils::KIND_DIR:
