@@ -35,7 +35,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Cambridge, MA 02110-1301, USA
 #include <KDirModel>
 #include <KIconLoader>
 #include <kio/global.h>
-#include <kmodelindexproxymapper.h>
+#include <KModelIndexProxyMapper>
 #include <KJobWidgets>
 
 // Local
