@@ -30,7 +30,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Cambridge, MA 02110-1301, USA
 // Qt
 #include <QPainter>
 #include <QTimer>
-#include <QDebug>
+#include "gwenview_lib_debug.h"
 
 namespace Gwenview
 {
