@@ -25,7 +25,6 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Cambridge, MA 02110-1301, USA
 #include <QCursor>
 #include <QGraphicsSvgItem>
 #include <QGraphicsTextItem>
-#include <QGraphicsWidget>
 #include <QPainter>
 #include <QSvgRenderer>
 #include "gwenview_lib_debug.h"
@@ -63,7 +62,7 @@ void SvgImageView::loadFromDocument()
     GV_RETURN_IF_FAIL(doc);
 
     if (doc->loadingState() == Document::Loaded) {
-        QMetaObject::invokeMethod(this, "finishLoadFromDocument", Qt::QueuedConnection);
+        QMetaObject::invokeMethod(this, &SvgImageView::finishLoadFromDocument, Qt::QueuedConnection);
     }
 
     // Ensure finishLoadFromDocument is also called when
