@@ -77,7 +77,7 @@ public:
 
     void setCursor(const QCursor&) override;
 
-    void setDocument(Document::Ptr) override;
+    void setDocument(const Document::Ptr &) override;
 
     Document::Ptr document() const override;
 
