@@ -36,7 +36,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Cambridge, MA 02110-1301, USA
 #include <QStyle>
 #include <QStyleOptionGraphicsItem>
 #include <QFontDatabase>
-#include <QDebug>
+#include "gwenview_lib_debug.h"
 
 namespace Gwenview
 {
