@@ -29,7 +29,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Cambridge, MA 02110-1301, USA
 #include <KDirModel>
 
 // Qt
-#include <QDebug>
+#include "gwenview_lib_debug.h"
 
 namespace Gwenview
 {
@@ -126,7 +126,7 @@ QVariant RecursiveDirModel::data(const QModelIndex& index, int role) const
     }
     KFileItem item = d->list().value(index.row());
     if (item.isNull()) {
-        qWarning() << "Invalid row" << index.row();
+        qCWarning(GWENVIEW_LIB_LOG) << "Invalid row" << index.row();
         return QVariant();
     }
     switch (role) {
@@ -137,7 +137,7 @@ QVariant RecursiveDirModel::data(const QModelIndex& index, int role) const
     case KDirModel::FileItemRole:
         return QVariant(item);
     default:
-        qWarning() << "Unhandled role" << role;
+        qCWarning(GWENVIEW_LIB_LOG) << "Unhandled role" << role;
         break;
     }
     return QVariant();
@@ -178,7 +178,7 @@ void RecursiveDirModel::slotItemsDeleted(const KFileItemList& list)
         }
         int row = d->rowForUrl(item.url());
         if (row == -1) {
-            qWarning() << "Received itemsDeleted for an unknown item: this should not happen!";
+            qCWarning(GWENVIEW_LIB_LOG) << "Received itemsDeleted for an unknown item: this should not happen!";
             GV_FATAL_FAILS;
             continue;
         }
