@@ -23,7 +23,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 
 // Qt
 #include <QImage>
-#include <QDebug>
+#include "gwenview_lib_debug.h"
 
 // KDE
 #include <KLocalizedString>
@@ -85,7 +85,7 @@ void ResizeImageOperation::redo()
 void ResizeImageOperation::undo()
 {
     if (!document()->editor()) {
-        qWarning() << "!document->editor()";
+        qCWarning(GWENVIEW_LIB_LOG) << "!document->editor()";
         return;
     }
     document()->editor()->setImage(d->mOriginalImage);
