@@ -30,8 +30,6 @@
 // Qt
 #include <QDir>
 #include <QFile>
-#include <QImage>
-#include <QPixmap>
 #include <QCryptographicHash>
 #include "gwenview_lib_debug.h"
 #include <QTemporaryFile>
@@ -315,7 +313,7 @@ void ThumbnailProvider::determineNextIcon()
     if (UrlUtils::urlIsFastLocalFile(mCurrentUrl)) {
         QFileInfo fileInfo(mCurrentUrl.toLocalFile());
         mOriginalTime = fileInfo.lastModified().toSecsSinceEpoch();
-        QMetaObject::invokeMethod(this, "checkThumbnail", Qt::QueuedConnection);
+        QMetaObject::invokeMethod(this, &ThumbnailProvider::checkThumbnail, Qt::QueuedConnection);
     } else {
         KIO::Job* job = KIO::stat(mCurrentUrl, KIO::HideProgressInfo);
         KJobWidgets::setWindow(job, qApp->activeWindow());
