@@ -31,7 +31,6 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Cambridge, MA 02110-1301, USA
 // Local
 #include <lib/thumbnailgroup.h>
 
-class QModelIndex;
 class QPixmap;
 class QSize;
 
@@ -44,7 +43,7 @@ class GWENVIEWLIB_EXPORT AbstractDocumentInfoProvider : public QObject
 {
     Q_OBJECT
 public:
-    AbstractDocumentInfoProvider(QObject* parent = 0);
+    explicit AbstractDocumentInfoProvider(QObject* parent = nullptr);
 
     /**
      * Returns true if the document is currently busy (loading, saving,
@@ -57,8 +56,8 @@ public:
     virtual void thumbnailForDocument(const QUrl &url, ThumbnailGroup::Enum, QPixmap* outPix, QSize* outFullSize) const = 0;
 
 Q_SIGNALS:
-    void busyStateChanged(const QModelIndex&, bool);
-    void documentChanged(const QModelIndex&);
+    void busyStateChanged(const QUrl& url, bool busy);
+    void documentChanged(const QUrl& url);
 };
 
 } // namespace
