@@ -44,7 +44,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Cambridge, MA 02110-1301, USA
 #include <KIconLoader>
 
 #ifndef GWENVIEW_SEMANTICINFO_BACKEND_NONE
-#include <kratingpainter.h>
+#include <KRatingPainter>
 #endif
 
 // Local
@@ -119,7 +119,7 @@ struct PreviewItemDelegatePrivate
     mutable ShadowCache mShadowCache;
 
     PreviewItemDelegate* q;
-    ThumbnailView* mView;
+    QPointer<ThumbnailView> mView;
     QWidget* mContextBar;
     QToolButton* mSaveButton;
     QPixmap mSaveButtonPixmap;
@@ -663,6 +663,10 @@ QSize PreviewItemDelegate::sizeHint(const QStyleOptionViewItem & /*option*/, con
 
 bool PreviewItemDelegate::eventFilter(QObject* object, QEvent* event)
 {
+    if (event->type() == QEvent::Destroy || event->type() == QEvent::ChildRemoved || !d->mView) {
+        return QItemDelegate::eventFilter(object, event);
+    }
+
     if (object == d->mView->viewport()) {
         switch (event->type()) {
         case QEvent::ToolTip:
