@@ -19,15 +19,14 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Cambridge, MA 02110-1301, USA
 
 */
 // Self
-#include "tooltipwidget.moc"
+#include "tooltipwidget.h"
 
 // Qt
 #include <QPainter>
 #include <QPainterPath>
-#include <QToolTip>
+#include "gwenview_lib_debug.h"
 
 // KDE
-#include <KDebug>
 #include <KColorScheme>
 
 // Local
