@@ -23,7 +23,6 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 #include <QPainter>
 
 // KDE
-#include <QDebug>
 #include <KJobUiDelegate>
 #include <KIO/StatJob>
 #include <QTest>
@@ -797,7 +796,7 @@ void DocumentTest::testUndoStackPush()
     protected:
         void redo() override
     {
-            QMetaObject::invokeMethod(this, "finish", Qt::QueuedConnection, Q_ARG(bool, true));
+            QMetaObject::invokeMethod(this, [this]() { finish(true); }, Qt::QueuedConnection);
         }
     };
 
@@ -806,7 +805,7 @@ void DocumentTest::testUndoStackPush()
     protected:
         void redo() override
     {
-            QMetaObject::invokeMethod(this, "finish", Qt::QueuedConnection, Q_ARG(bool, false));
+            QMetaObject::invokeMethod(this, [this]() { finish(false); }, Qt::QueuedConnection);
         }
     };
 
