@@ -25,7 +25,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Cambridge, MA 02110-1301, USA
 #include <lib/slidecontainer.h>
 
 // KDE
-#include <qtest.h>
+#include <QTest>
 
 // Qt
 #include <QTextEdit>
