@@ -26,7 +26,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 // KDE
 #include <KFileItem>
 #include <QTemporaryFile>
-#include <qtest.h>
+#include <QTest>
 
 // Local
 #include "../lib/timeutils.h"
